# DeltaPI
# Group #14
This repository contains CS207, fall 2019, final project.
## Group Members
* Daniel Cox
* Anna Davydova
* Stephen Moon
* Valentina Toll Villagra
### Badges:
[![Build Status](https://travis-ci.com/IACS-CS-207-FantasticFour/cs207-FinalProject.svg?branch=master)](https://travis-ci.com/IACS-CS-207-FantasticFour/cs207-FinalProject)
[![codecov](https://codecov.io/gh/IACS-CS-207-FantasticFour/cs207-FinalProject/branch/master/graph/badge.svg)](https://codecov.io/gh/IACS-CS-207-FantasticFour/cs207-FinalProject)

This project aims to deliver an Automatic Differentiation Software DeltaPi that will calculate derivatives efficiently and accurately, making it useful across a wide spectrum of applications. In this package, we will execute the forward mode of Automatic Differentiation. We will also provide an extension package HedgeDeltaPi that will calculate delta for European Call and Put options, allowing for efficient delta hedging.